@@ -1,5 +1,53 @@
 '''
-# replace this
+# AWS Lambda function with Flyway
+
+## Flyway --> Migrate/Evolve your database schema
+
+Flyway is an opensource tool to easily evolve your db : https://flywaydb.org/
+
+## Flyway Migration Construct
+
+This AWS CDK construct allows you to scale your db schema with a lambda function.
+
+The lambda function code is upload on S3 bucket "flywaymigrationconstruct". The construct retrieves the code on it according
+to the version of the construct.
+
+You must pass arguments, most of which are optional and are parameters of your lambda function except two of them,
+which are environment variables.
+
+## Migration DB SecretManager
+
+Migration DB SecretManager is the Secret of the DB you want to manage with Flyway.
+It has to have 6 arguments :
+
+username : the username of your DB
+
+password : the password of your DB
+
+engine : the type of your db (Redshift, Aurora MySQL, ...)
+
+host: the host of your DB
+
+port: the port of your DB
+
+dbname: the name of your DB
+
+## Bucket Migration SQL
+
+Bucket Migration SQL is the S3 Bucket where you will put your SQL files
+(warning : you have to comply with the naming pattern of Flyway).
+
+## Enable in Python and TS (maybe more soon):
+
+PyPI: https://pypi.org/project/flywaymigrationconstruct/
+
+npmjs: https://www.npmjs.com/package/flywaymigrationconstruct
+
+## NB :
+
+Flyway Migration Construct manages the lambda function permissions for the secret and the bucket.
+
+Warning : Version 0.2.0 only allows DB on Amazon Redshift
 '''
 import abc
 import builtins
@@ -30,33 +78,33 @@ class FlywayConstruct(
         scope: aws_cdk.core.Construct,
         id: builtins.str,
         *,
-        bucket: aws_cdk.aws_s3.IBucket,
-        migration_bucket_secret_manager: aws_cdk.aws_secretsmanager.ISecret,
-        security_groups: typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup],
-        subnet: aws_cdk.aws_ec2.SubnetSelection,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        bucket_migration_sql: aws_cdk.aws_s3.IBucket,
+        migration_db_secret_manager: aws_cdk.aws_secretsmanager.ISecret,
         memory_size: typing.Optional[jsii.Number] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+        subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
         :param scope: -
         :param id: -
-        :param bucket: 
-        :param migration_bucket_secret_manager: 
+        :param bucket_migration_sql: 
+        :param migration_db_secret_manager: 
+        :param memory_size: 
         :param security_groups: 
         :param subnet: 
-        :param vpc: 
-        :param memory_size: 
         :param timeout: 
+        :param vpc: 
         '''
         params = FlywayConstructParams(
-            bucket=bucket,
-            migration_bucket_secret_manager=migration_bucket_secret_manager,
+            bucket_migration_sql=bucket_migration_sql,
+            migration_db_secret_manager=migration_db_secret_manager,
+            memory_size=memory_size,
             security_groups=security_groups,
             subnet=subnet,
-            vpc=vpc,
-            memory_size=memory_size,
             timeout=timeout,
+            vpc=vpc,
         )
 
         jsii.create(FlywayConstruct, self, [scope, id, params])
@@ -95,90 +143,92 @@ class FlywayConstruct(
     jsii_type="flywaymigrationconstruct.FlywayConstructParams",
     jsii_struct_bases=[],
     name_mapping={
-        "bucket": "bucket",
-        "migration_bucket_secret_manager": "migrationBucketSecretManager",
+        "bucket_migration_sql": "bucketMigrationSQL",
+        "migration_db_secret_manager": "migrationDBSecretManager",
+        "memory_size": "memorySize",
         "security_groups": "securityGroups",
         "subnet": "subnet",
-        "vpc": "vpc",
-        "memory_size": "memorySize",
         "timeout": "timeout",
+        "vpc": "vpc",
     },
 )
 class FlywayConstructParams:
     def __init__(
         self,
         *,
-        bucket: aws_cdk.aws_s3.IBucket,
-        migration_bucket_secret_manager: aws_cdk.aws_secretsmanager.ISecret,
-        security_groups: typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup],
-        subnet: aws_cdk.aws_ec2.SubnetSelection,
-        vpc: aws_cdk.aws_ec2.IVpc,
+        bucket_migration_sql: aws_cdk.aws_s3.IBucket,
+        migration_db_secret_manager: aws_cdk.aws_secretsmanager.ISecret,
         memory_size: typing.Optional[jsii.Number] = None,
+        security_groups: typing.Optional[typing.Sequence[aws_cdk.aws_ec2.ISecurityGroup]] = None,
+        subnet: typing.Optional[aws_cdk.aws_ec2.SubnetSelection] = None,
         timeout: typing.Optional[aws_cdk.core.Duration] = None,
+        vpc: typing.Optional[aws_cdk.aws_ec2.IVpc] = None,
     ) -> None:
         '''
-        :param bucket: 
-        :param migration_bucket_secret_manager: 
+        :param bucket_migration_sql: 
+        :param migration_db_secret_manager: 
+        :param memory_size: 
         :param security_groups: 
         :param subnet: 
-        :param vpc: 
-        :param memory_size: 
         :param timeout: 
+        :param vpc: 
         '''
         if isinstance(subnet, dict):
             subnet = aws_cdk.aws_ec2.SubnetSelection(**subnet)
         self._values: typing.Dict[str, typing.Any] = {
-            "bucket": bucket,
-            "migration_bucket_secret_manager": migration_bucket_secret_manager,
-            "security_groups": security_groups,
-            "subnet": subnet,
-            "vpc": vpc,
+            "bucket_migration_sql": bucket_migration_sql,
+            "migration_db_secret_manager": migration_db_secret_manager,
         }
         if memory_size is not None:
             self._values["memory_size"] = memory_size
+        if security_groups is not None:
+            self._values["security_groups"] = security_groups
+        if subnet is not None:
+            self._values["subnet"] = subnet
         if timeout is not None:
             self._values["timeout"] = timeout
+        if vpc is not None:
+            self._values["vpc"] = vpc
 
     @builtins.property
-    def bucket(self) -> aws_cdk.aws_s3.IBucket:
-        result = self._values.get("bucket")
-        assert result is not None, "Required property 'bucket' is missing"
+    def bucket_migration_sql(self) -> aws_cdk.aws_s3.IBucket:
+        result = self._values.get("bucket_migration_sql")
+        assert result is not None, "Required property 'bucket_migration_sql' is missing"
         return typing.cast(aws_cdk.aws_s3.IBucket, result)
 
     @builtins.property
-    def migration_bucket_secret_manager(self) -> aws_cdk.aws_secretsmanager.ISecret:
-        result = self._values.get("migration_bucket_secret_manager")
-        assert result is not None, "Required property 'migration_bucket_secret_manager' is missing"
+    def migration_db_secret_manager(self) -> aws_cdk.aws_secretsmanager.ISecret:
+        result = self._values.get("migration_db_secret_manager")
+        assert result is not None, "Required property 'migration_db_secret_manager' is missing"
         return typing.cast(aws_cdk.aws_secretsmanager.ISecret, result)
 
-    @builtins.property
-    def security_groups(self) -> typing.List[aws_cdk.aws_ec2.ISecurityGroup]:
-        result = self._values.get("security_groups")
-        assert result is not None, "Required property 'security_groups' is missing"
-        return typing.cast(typing.List[aws_cdk.aws_ec2.ISecurityGroup], result)
-
-    @builtins.property
-    def subnet(self) -> aws_cdk.aws_ec2.SubnetSelection:
-        result = self._values.get("subnet")
-        assert result is not None, "Required property 'subnet' is missing"
-        return typing.cast(aws_cdk.aws_ec2.SubnetSelection, result)
-
-    @builtins.property
-    def vpc(self) -> aws_cdk.aws_ec2.IVpc:
-        result = self._values.get("vpc")
-        assert result is not None, "Required property 'vpc' is missing"
-        return typing.cast(aws_cdk.aws_ec2.IVpc, result)
-
     @builtins.property
     def memory_size(self) -> typing.Optional[jsii.Number]:
         result = self._values.get("memory_size")
         return typing.cast(typing.Optional[jsii.Number], result)
 
+    @builtins.property
+    def security_groups(
+        self,
+    ) -> typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]]:
+        result = self._values.get("security_groups")
+        return typing.cast(typing.Optional[typing.List[aws_cdk.aws_ec2.ISecurityGroup]], result)
+
+    @builtins.property
+    def subnet(self) -> typing.Optional[aws_cdk.aws_ec2.SubnetSelection]:
+        result = self._values.get("subnet")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.SubnetSelection], result)
+
     @builtins.property
     def timeout(self) -> typing.Optional[aws_cdk.core.Duration]:
         result = self._values.get("timeout")
         return typing.cast(typing.Optional[aws_cdk.core.Duration], result)
 
+    @builtins.property
+    def vpc(self) -> typing.Optional[aws_cdk.aws_ec2.IVpc]:
+        result = self._values.get("vpc")
+        return typing.cast(typing.Optional[aws_cdk.aws_ec2.IVpc], result)
+
     def __eq__(self, rhs: typing.Any) -> builtins.bool:
         return isinstance(rhs, self.__class__) and rhs._values == self._values
 
